SineWaveConfig class

进度条已走部分的正弦波浪线动画配置。

传入到 ProgressBar.sineWaveConfig 时,已走部分以流动的正弦波浪动画填充。 传入 null(默认值)则渲染平直进度条。

Constructors

SineWaveConfig({double amplitude = 3.0, double cycleCount = 2.0, double speed = 1.0, Color? waveColor, int waveCount = 1, bool clampToBarBounds = false, double? reservedAmplitude})
const

Properties

amplitude double
正弦波偏离中心线的峰值幅度,单位逻辑像素。默认 3.0。
final
clampToBarBounds bool
是否将波浪裁剪到进度条边界内。
final
cycleCount double
可见进度宽度上的完整周期数。默认 2.0。
final
effectiveAmplitude double
实际用于计算组件高度的振幅值。
no setter
hashCode int
The hash code for this object.
no setteroverride
reservedAmplitude double?
预留振幅高度。组件高度始终按此值与 amplitude 中的较大者计算, 避免调整振幅时进度条高度跟随变化。默认 null 时仅按 amplitude 计算。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
动画速度倍率。1.0 为基准速度,2.0 为两倍速度。
final
waveColor Color?
波浪颜色覆盖,null 时使用 progressBarColor。
final
waveCount int
叠加波浪层数,>1 时产生丰富波纹效果。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override