TimeLabelLocation enum
时间标签相对于进度条的位置。
Values
- above → const TimeLabelLocation
-
时间标签显示在进度条上方。
- below → const TimeLabelLocation
-
时间标签显示在进度条下方。
- sides → const TimeLabelLocation
-
时间标签显示在进度条两侧。
- none → const TimeLabelLocation
-
不显示时间标签。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TimeLabelLocation> - A constant List of the values in this enum, in order of their declaration.